<?php

class UpdatablePluginClass {
	
	var $file;
	var $detailsurl;
	
	function __construct($file) {
		$this->file = WP_PLUGIN_DIR.'/'.$file.'/'.$file.'.php';
		$this->detailsurl = 'http://theme.gulfoilltd.com/plugins/'.$file.'/details.json';
		add_filter( 'http_request_args', array($this,'updates_exclude'), 5, 2 );
		
		add_filter('pre_set_site_transient_update_themes', array($this, 'check_update'));
		register_activation_hook($this->file, array($this,'check_activation'));
		add_action('updatablepluginclass_check_event', array($this,'check_update'));
		register_deactivation_hook($this->file, array($this,'check_deactivation'));
	}
	
	//Exclude from WP updates
	function updates_exclude( $r, $url ) {
		if ( 0 !== strpos( $url, 'http://api.wordpress.org/plugins/update-check' ) )
			return $r; // Not a plugin update request. Bail immediately.
		$plugins = unserialize( $r['body']['plugins'] );
		unset( $plugins->plugins[ plugin_basename( __FILE__ ) ] );
		unset( $plugins->active[ array_search( plugin_basename( __FILE__ ), $plugins->active ) ] );
		$r['body']['plugins'] = serialize( $plugins );
		return $r;
	}


	//Returns current plugin info.
	function plugin_get($i) {
		if ( ! function_exists( 'get_plugins' ) )
			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		$plugin_folder = get_plugins( '/' . plugin_basename( dirname( $this->file ) ) );
		$plugin_file = basename( ( $this->file ) );
		return $plugin_folder[$plugin_file][$i];
	}

	//check for update twice a day (same schedule as normal WP plugins)
	function check_activation() {
		wp_schedule_event(time(), 'twicedaily', 'updatablepluginclass_check_event');
	}
	function check_update() {
		$plugin_folder = plugin_basename( dirname( $this->file ) );
		$plugin_file = basename( ( $this->file ) );
		if ( defined( 'WP_INSTALLING' ) ) return false;

		$response = wp_remote_get( $this->detailsurl );
		$details = json_decode($response['body']);
		$version = $details->version;

		if($this->plugin_get("Version") == $version) return false;
		$plugin_transient = get_site_transient('update_plugins');
		$a = array(
			'slug' => $plugin_folder,
			'new_version' => $version,
			'url' => $this->plugin_get("AuthorURI"),
			'package' => $details->download_url,
		);
		$o = (object) $a;
		$plugin_transient->response[$plugin_folder.'/'.$plugin_file] = $o;
		set_site_transient('update_plugins', $plugin_transient);
	}

	//remove cron task upon deactivation
	function check_deactivation() {
		wp_clear_scheduled_hook('updatablepluginclass_check_event');
	}

	
}

